import { PagedStudies, Study } from './ctg-api';
export { Study };
/**
 * The default endpoint if none is specified: the clinicaltrials.gov v2 API
 * endpoint.
 */
export declare const DEFAULT_ENDPOINT = "https://clinicaltrials.gov/api/v2";
type Logger = (message: string, ...param: unknown[]) => void;
/**
 * Type guard for checking the response from the server. Exported for tests.
 * @param o the object to check
 * @returns
 */
export declare function isPagedStudies(o: unknown): o is PagedStudies;
/**
 * Class that provides a method for invoking the ClinicalTrials.gov V2 API using
 * the built-in Node.js HTTPS library.
 */
export declare class ClinicalTrialsGovAPI {
    private _log;
    private _endpoint;
    /**
     * Maximum number of redirects before giving up.
     */
    _maxRedirects: number;
    constructor(options?: {
        logger?: Logger;
        endpoint?: string;
    });
    /**
     * Fetches the given list of NCT IDs.
     * @param nctIds the NCT IDs to fetch
     * @returns a promise that resolves to the list of studies
     */
    fetchStudies(nctIds: string[], pageSize?: number): Promise<Study[]>;
    getUrl(url: string): Promise<unknown>;
}
export default ClinicalTrialsGovAPI;
