"use strict";
/**
 * FHIR type guards for ensuring that objects match (at least to some degree) a
 * valid FHIR R4 type.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isFhirDate = exports.isResearchStudy = exports.isBundle = void 0;
const BUNDLE_TYPES = new Set([
    'document',
    'message',
    'transaction',
    'transaction-response',
    'batch',
    'batch-response',
    'history',
    'searchset',
    'collection'
]);
function isBundle(o) {
    if (typeof o !== 'object' || o === null)
        return false;
    const other = o;
    return other.resourceType === 'Bundle' && BUNDLE_TYPES.has(other.type) && Array.isArray(other.entry);
}
exports.isBundle = isBundle;
function isResearchStudy(o) {
    if (typeof o !== 'object' || o === null) {
        return false;
    }
    return o.resourceType === 'ResearchStudy';
}
exports.isResearchStudy = isResearchStudy;
/**
 * Determines if the given string is a valid FHIR date.
 * @param str the date string to check
 */
function isFhirDate(str) {
    // This RegExp is from the FHIR spec itself:
    // http://hl7.org/fhir/R4/datatypes.html#dateTime
    return /^([0-9]([0-9]([0-9][1-9]|[1-9]0)|[1-9]00)|[1-9]000)(-(0[1-9]|1[0-2])(-(0[1-9]|[1-2][0-9]|3[0-1])(T([01][0-9]|2[0-3]):[0-5][0-9]:([0-5][0-9]|60)(\.[0-9]+)?(Z|(\+|-)((0[0-9]|1[0-3]):[0-5][0-9]|14:00)))?)?)?$/.test(str);
}
exports.isFhirDate = isFhirDate;
