"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resourceContainsProfile = void 0;
/**
 * Checks to see if a given resource contains a requested profile.
 * @param resource the FHIR resource to check
 * @param profile the profile string to look up
 * @returns true if the profile exists on the resource
 */
function resourceContainsProfile(resource, profile) {
    // Check to see if there are any profiles at all
    const meta = resource.meta;
    if (typeof meta !== 'object' || meta === null) {
        return false;
    }
    const profiles = meta.profile;
    if (!Array.isArray(profiles)) {
        return false;
    }
    // Otherwise, see if any profile has this array
    if (typeof profile === 'string') {
        return profiles.includes(profile);
    }
    else {
        // RegExp, test each profile with it (useful for looser matching)
        return profiles.some(p => profile.test(p));
    }
}
exports.resourceContainsProfile = resourceContainsProfile;
