import * as fhir from 'fhir/r4';
export interface ReasonReference {
    reference?: string;
    display?: string;
    meta_profile?: string;
}
export interface Quantity {
    value?: number | string;
    comparator?: string;
    unit?: string;
    system?: string;
    code?: string;
}
export interface Ratio {
    numerator?: Quantity;
    denominator?: Quantity;
}
export interface BaseFhirResource {
    coding: fhir.Coding[];
}
export interface CancerConditionParent extends BaseFhirResource {
    clinicalStatus: fhir.Coding[];
    meta_profile: string;
    id?: string;
}
export interface PrimaryCancerCondition extends CancerConditionParent {
    histologyMorphologyBehavior: fhir.Coding[];
}
export interface SecondaryCancerCondition extends CancerConditionParent {
    bodySite: fhir.Coding[];
}
export interface BaseCancerRelatedProcedure extends BaseFhirResource {
    bodySite: fhir.Coding[];
}
export interface CancerRelatedRadiationProcedure extends BaseCancerRelatedProcedure {
    mcodeTreatmentIntent: fhir.Coding[];
}
export interface CancerRelatedSurgicalProcedure extends BaseCancerRelatedProcedure {
    reasonReference: ReasonReference[];
}
export interface TumorMarker extends BaseFhirResource {
    valueQuantity?: Quantity;
    valueRatio?: Ratio;
    valueCodeableConcept: fhir.Coding[];
    interpretation: fhir.Coding[];
}
export interface CancerGeneticVariant extends BaseFhirResource {
    component: CancerGeneticVariantComponent;
    valueCodeableConcept: fhir.Coding[];
    interpretation: fhir.Coding[];
}
export interface CancerGeneticVariantComponent {
    geneStudied: fhir.ObservationComponent[];
    genomicsSourceClass: fhir.ObservationComponent[];
}
/**
 * Extract coding from a codeable concept. Exported to allow testing.
 * @param codeableConcept the codeable concept to check
 * @return either the coding values or an empty array if not found
 */
export declare function extractCoding(codeableConcept: fhir.CodeableConcept[] | fhir.CodeableConcept | undefined): fhir.Coding[];
/**
 * Class that extracts mCODE data from a patient record.
 */
export declare class mCODEextractor {
    /**
     * Extracted primary cancer conditions.
     */
    readonly primaryCancerConditions: PrimaryCancerCondition[];
    readonly secondaryCancerConditions: SecondaryCancerCondition[];
    readonly TNMClinicalStageGroups: fhir.Coding[];
    readonly TNMPathologicalStageGroups: fhir.Coding[];
    /**
     * Birth date. String if date was found, null if a birth date was not given.
     */
    readonly birthDate: string | null;
    readonly tumorMarkers: TumorMarker[];
    readonly cancerGeneticVariants: CancerGeneticVariant[];
    readonly cancerRelatedRadiationProcedures: CancerRelatedRadiationProcedure[];
    readonly cancerRelatedSurgicalProcedures: CancerRelatedSurgicalProcedure[];
    readonly cancerRelatedMedicationStatements: fhir.Coding[];
    /**
     * Extracted ECOG performance status, or -1 if not found.
     */
    readonly ecogPerformanceStatus: number;
    /**
     * Extracted Karnofsky performance status, or -1 if not found.
     */
    readonly karnofskyPerformanceStatus: number;
    /**
     * Constructor.
     * @param patientBundle The patient bundle to build the mCODE mapping from.
     */
    constructor(patientBundle: fhir.Bundle);
    /**
     * Checks whether the given list contains the given coding.
     * @param codingList
     * @param coding
     * @returns
     */
    private contains;
    /**
     * Adds the given coding to the given coding list.
     * @param codingList
     * @param codes the codes to add - if undefined, nothing is added (undefined
     *    is allowed to make checking easier)
     * @returns
     */
    private addCoding;
    /**
     * Returns whether the given list contains the given procedure.
     * @param procedureList
     * @param procedure
     * @returns
     */
    listContainsProcedure(procedureList: BaseCancerRelatedProcedure[], procedure: BaseCancerRelatedProcedure): boolean;
}
